<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.UI.Core.Preview.Communications

Windows Runtime (WinRT) APIs for for the `Windows.UI.Core.Preview.Communications` namespace.

This package provides the `winrt.windows.ui.core.preview.communications` module.
